Calculate any expression using the existing tags.
NOTE: all expressions must follow the format:
[]?
where
base-date is either absolute date long or short format (YYYY-MM-DD) or and special date
like today or sun
operation is either + or -
single-range is the same format as recurrence #R (a number followed by a range type DWMY),
if range type is missing, it defaults to d=days
Examples:
due+2 ==> 2 days after due date
due+2d ==> the same as above: 2 days after due date
t-2w ==> 2 weeks before threshold date
due+1w+2d ==> 1 week and 2 days after due date
Replaces the current tag values in a string with new calculated values.
The tag value is replaced only if the tag has TagValueType::Calc type.
The current list of replaced tags is short: due and t.